=======================
The weylchamber package
=======================

Python package for analyzing two-qubit gates in the Weyl chamber

Development of the ``weylchamber`` package happens on `Github`_.
You can read the full documentation `online`_.


.. _online: https://qucontrol.github.io/weylchamber/


Installation
------------

To install the latest released version of the ``weylchamber`` package, run this command in your terminal:

.. code-block:: console

    $ pip install weylchamber

This is the preferred method to install ``weylchamber``, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


To install the latest development version of ``weylchamber`` from `Github`_.

.. code-block:: console

    $ pip install git+https://github.com/qucontrol/weylchamber.git@master#egg=weylchamber



.. _Github: https://github.com/qucontrol/weylchamber

Usage
-----

To use ``weylchamber`` in a project::

    import weylchamber

See the Tutorial_ for details.

.. _Tutorial: https://qucontrol.github.io/weylchamber/master/tutorial.html
